@@ -12,10 +12,10 @@ class Game;
 
 class QAction;
 class KActionMenu;
-class KGameRenderer;
+class KGameGraphicsViewRenderer;
 
 #include <KXmlGuiWindow>
-#include <KgThemeSelector>
+#include <KGameThemeSelector>
 
 namespace KDiamond
 {
@@ -54,8 +54,8 @@ private:
     QAction *m_newUntimedAct;
     QAction *m_pauseAct;
     QAction *m_hintAct;
-    KGameRenderer *m_renderer;
-    KgThemeSelector m_selector;
+    KGameGraphicsViewRenderer *m_renderer;
+    KGameThemeSelector m_selector;
 };
 
 #endif //KDIAMOND_MAINWINDOW_H
